import { CandyMachineIsFullError, CandyMachineCannotAddAmountError, CandyMachineAddConfigConstraintsViolatedError } from '../../errors/CandyMachineError.mjs';
import { CandyMachineAccount } from '../../programs/candyMachine/accounts/CandyMachineAccount.mjs';

function creatorsToJsonMetadataCreators(creators) {
  return creators.map(creator => ({
    address: creator.address.toBase58(),
    share: creator.share,
    verified: creator.verified
  }));
}
function assertNotFull(candyMachine, index) {
  if (candyMachine.isFull) {
    throw new CandyMachineIsFullError(index, candyMachine.maxSupply);
  }
}
function assertCanAdd(candyMachine, index, amount) {
  if (index + amount > candyMachine.maxSupply) {
    throw new CandyMachineCannotAddAmountError(index, amount, candyMachine.maxSupply);
  }
}
function assertAllConfigLineConstraints(configLines) {
  for (let i = 0; i < configLines.length; i++) {
    assertConfigLineConstraints(configLines[i], i);
  }
}

function assertConfigLineConstraints(configLine, index) {
  try {
    CandyMachineAccount.assertConfigLineConstraints(configLine);
  } catch (err) {
    throw new CandyMachineAddConfigConstraintsViolatedError(index, configLine, err);
  }
}

export { assertAllConfigLineConstraints, assertCanAdd, assertNotFull, creatorsToJsonMetadataCreators };
//# sourceMappingURL=Client.helpers.mjs.map
